@@ -36,7 +36,7 @@ package App::Dochazka::CLI;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use App::CELL qw( $CELL );
 use Data::Dumper;
@@ -53,11 +53,11 @@ App::Dochazka::CLI - Dochazka command line client
 
 =head1 VERSION
 
-Version 0.217
+Version 0.218
 
 =cut
 
-our $VERSION = '0.217';
+our $VERSION = '0.218';
 
 
 
